/*
 * Copyright (c) 2013, Patrick Moawad
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.google.code.validationframework.swing.decoration;

import com.google.code.validationframework.swing.decoration.AbstractComponentDecoration;
import com.google.code.validationframework.swing.decoration.anchor.Anchor;
import com.google.code.validationframework.swing.decoration.anchor.AnchorLink;
import org.junit.Test;

import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.JTextField;
import java.awt.Graphics;

public class AbstractComponentDecorationTest {

    private static class DummyComponentDecoration extends AbstractComponentDecoration {

        /**
         * @see AbstractComponentDecoration#AbstractComponentDecoration(JComponent, AnchorLink)
         */
        public DummyComponentDecoration(final JComponent decoratedComponent, final AnchorLink anchorLink) {
            super(decoratedComponent, anchorLink);
        }

        /**
         * @see AbstractComponentDecoration#getWidth()
         */
        @Override
        protected int getWidth() {
            return 16;
        }

        /**
         * @see AbstractComponentDecoration#getHeight()
         */
        @Override
        protected int getHeight() {
            return 16;
        }

        /**
         * @see AbstractComponentDecoration#paint(Graphics)
         */
        @Override
        public void paint(final Graphics g) {
            // Nothing to be done
        }
    }

    @Test
    public void testMultipleDispose() {
        final JFrame frame = new JFrame();
        final JTextField textField = new JTextField();
        frame.setContentPane(textField);

        final DummyComponentDecoration decoration = new DummyComponentDecoration(textField,
                new AnchorLink(Anchor.TOP_LEFT, Anchor.TOP_LEFT));

        decoration.setVisible(false);
        decoration.setVisible(true);
        decoration.dispose();
        decoration.dispose();
        decoration.dispose();
        decoration.setVisible(false);
        decoration.setVisible(true);
    }
}
